@@ -3,10 +3,9 @@ use strict;
 
 BEGIN {
     use Exporter();
-    use vars qw ($VERSION @ISA @EXPORT $times );
+    use vars qw (@ISA @EXPORT $times );
     use Acme::Time::FooClock;
 
-    $VERSION   = 1.12;
     @ISA       = qw (Exporter Acme::Time::FooClock);
     @EXPORT = qw ( veggietime );
 
